@@ -282,14 +282,14 @@ def _path_matches(request_path, path_pattern):
     # The fnmatch module doesn't provide the ability to match * versus **,
     # so convert to regex.
     token_regex = (r'(?P<tag>{[^}]*})|'  # {tag} # nosec
-                   '(?P<wild>\*(?=$|[^\*]))|'  # *
-                   '(?P<rec_wild>\*\*)|'  # **
-                   '(?P<literal>[^{}\*])')  # anything else
+                   r'(?P<wild>\*(?=$|[^\*]))|'  # *
+                   r'(?P<rec_wild>\*\*)|'  # **
+                   r'(?P<literal>[^{}\*])')  # anything else
     path_regex = ''
     for match in re.finditer(token_regex, path_pattern):
         token = match.groupdict()
         if token['tag'] or token['wild']:
-            path_regex += '[^\/]+'
+            path_regex += r'[^\/]+'
         if token['rec_wild']:
             path_regex += '.*'
         if token['literal']:
@@ -822,7 +822,7 @@ class AuthProtocol(BaseAuthProtocol):
         plugin_opts = loading.get_auth_plugin_conf_options(plugin_loader)
 
         self._conf.oslo_conf_obj.register_opts(plugin_opts, group=group)
-        getter = lambda opt: self._conf.get(opt.dest, group=group)
+        getter = lambda opt: self._conf.get(opt.dest, group=group)  # noqa
         return plugin_loader.load_from_options_getter(getter)
 
     def _create_session(self, **kwargs):
